package cn.com.infosec.asn1.cms;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1Set;
import cn.com.infosec.asn1.BERSequence;
import cn.com.infosec.asn1.BERTaggedObject;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERObject;

public class EncryptedData extends ASN1Encodable {
   private DERInteger version;
   private EncryptedContentInfo encryptedContentInfo;
   private ASN1Set unprotectedAttrs;

   public static EncryptedData getInstance(Object o) {
      if (o instanceof EncryptedData) {
         return (EncryptedData)o;
      } else if (o instanceof ASN1Sequence) {
         return new EncryptedData((ASN1Sequence)o);
      } else {
         throw new IllegalArgumentException("Invalid EncryptedData: " + o.getClass().getName());
      }
   }

   public EncryptedData(EncryptedContentInfo encInfo) {
      this(encInfo, (ASN1Set)null);
   }

   public EncryptedData(EncryptedContentInfo encInfo, ASN1Set unprotectedAttrs) {
      DERInteger var3 = new DERInteger;
      byte var4;
      if (unprotectedAttrs == null) {
         var4 = 0;
      } else {
         var4 = 2;
      }

      var3.<init>(var4);
      this.version = var3;
      this.encryptedContentInfo = encInfo;
      this.unprotectedAttrs = unprotectedAttrs;
   }

   private EncryptedData(ASN1Sequence seq) {
      this.version = DERInteger.getInstance(seq.getObjectAt(0));
      this.encryptedContentInfo = EncryptedContentInfo.getInstance(seq.getObjectAt(1));
      if (seq.size() == 3) {
         this.unprotectedAttrs = ASN1Set.getInstance(seq.getObjectAt(2));
      }

   }

   public DERInteger getVersion() {
      return this.version;
   }

   public EncryptedContentInfo getEncryptedContentInfo() {
      return this.encryptedContentInfo;
   }

   public ASN1Set getUnprotectedAttrs() {
      return this.unprotectedAttrs;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10001 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var1.add(this.version);
      var10001.add(this.encryptedContentInfo);
      ASN1Set var3;
      if ((var3 = this.unprotectedAttrs) != null) {
         BERTaggedObject var2;
         var2 = new BERTaggedObject.<init>(false, 1, var3);
         var1.add(var2);
      }

      return new BERSequence(var1);
   }
}
